@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "guava-themes" "0.11.2"
+(define-package "guava-themes" "20260121.2115"
   "A pack of plant-inspired themes."
   '((emacs "24.1"))
-  :url "https://github.com/bormoge/guava-themes"
-  :commit "39995a2de698b9f407b86a25dca2b9d8d23641e5"
-  :revdesc "v0.11.2-0-g39995a2de698"
+  :url "http://github.com/bormoge/guava-themes"
+  :commit "38ca52de6b8b9a70ca0e1f5344d3f4caa4d81a3a"
+  :revdesc "38ca52de6b8b"
   :keywords '("themes" "faces" "color")
   :authors '(("Geralld Borbón" . "eternalmangocean@gmail.com"))
   :maintainers '(("Geralld Borbón" . "eternalmangocean@gmail.com")))
